@@ -339,7 +339,6 @@ class TestPrologMQI(ParametrizedTestCase):
                 result = client.query("test_goal_expansion(2, Out)")
                 assert [{'Out': {'x': 2, 'y': 2, 'z': 0}}] == result
 
-
     def test_sync_query(self):
         if self.essentialOnly:
             print("skipped", flush=True, end=" ")
@@ -458,10 +457,15 @@ class TestPrologMQI(ParametrizedTestCase):
                 # Async queries with all results
                 ##########
 
+                # Most basic async query that fails with all results and no free variables
+                client.query_async("false", find_all=True)
+                result = client.query_async_result()
+                assert False is result
+
                 # Most basic async query with all results and no free variables
                 client.query_async("atom(a)", find_all=True)
                 result = client.query_async_result()
-                assert True == result
+                assert True is result
 
                 # Use characters that are encoded in UTF8 in: a one byte (1) two bytes (©) and three bytes (≠)
                 # To test message format and make sure it handles non-ascii characters
@@ -492,6 +496,12 @@ class TestPrologMQI(ParametrizedTestCase):
                 # Async queries with individual results
                 ##########
 
+                # Most basic async query that fails with all results and no free variables and find_all is False
+                client.query_async("false", find_all=False)
+                result = client.query_async_result()
+                assert False is result
+
+
                 # async query that has a parse error
                 query = "member(X, [first, second, third]"
                 caughtException = False
@@ -877,6 +887,9 @@ class TestPrologMQI(ParametrizedTestCase):
 
     def test_server_options_and_shutdown(self):
         global secondsTimeoutForThreadExit
+        if self.essentialOnly:
+            print("skipped", flush=True, end=" ")
+            return
         try:
             with PrologMQI(
                 self.launchServer,
@@ -911,10 +924,8 @@ class TestPrologMQI(ParametrizedTestCase):
                     afterShutdownThreads = self.thread_list(monitorThread)
                     self.wait_for_new_threads_exit(monitorThread, initialThreads, afterShutdownThreads, secondsTimeoutForThreadExit)
 
-                    if os.name != "nt":
-                        # unixDomainSocket() should be used if supplied (non-windows).
-                        socketPath = mkdtemp()
-                        unixDomainSocket = PrologMQI.unix_domain_socket_file(socketPath)
+                    unixDomainSocket = unix_domain_socket_path_if_available()
+                    if unixDomainSocket:
                         result = monitorThread.query(
                             f"mqi_start([unix_domain_socket('{unixDomainSocket}'), password(testpassword), server_thread(ServerThreadID)])"
                         )
@@ -1017,7 +1028,7 @@ class TestPrologMQI(ParametrizedTestCase):
                 # Rethrow the exception if we are configured to fail on unlikely tests failures
                 raise
             else:
-                stackTrace = ''.join(traceback.format_exception(etype=type(e), value=e, tb=e.__traceback__))
+                stackTrace = ''.join(traceback.format_exception(e, e, e.__traceback__))
                 print(
                     f"WARNING: {e} at {stackTrace}.\n This can happen if the system is heavily loaded and is thus a warning by default. To turn this into a failure set the environment variable 'SWIPL_TEST_FAIL_ON_UNLIKELY=y'."
                 )
@@ -1130,7 +1141,7 @@ class TestPrologMQI(ParametrizedTestCase):
                 self.wait_for_new_threads_exit(monitorThread, initialThreads, afterShutdownThreads, secondsTimeoutForThreadExit)
 
     def test_unix_domain_socket_embedded(self):
-        if os.name != "nt":
+        if unix_domain_socket_path_if_available():
             with PrologMQI(
                 launch_mqi=True,
                 unix_domain_socket="",
@@ -1141,7 +1152,6 @@ class TestPrologMQI(ParametrizedTestCase):
                     result = prologThread.query("true")
                     self.assertEqual(result, True)
 
-
     def test_python_classes(self):
         # Using a thread without starting it should start the server
         with PrologMQI(
@@ -1318,6 +1328,52 @@ class TestPrologMQI(ParametrizedTestCase):
                 with PrologThread(server) as prolog_thread:
                     prolog_thread.query("true")
 
+    def test_serialization_exceptions(self):
+        with PrologMQI(
+            self.launchServer,
+            self.serverPort,
+            self.password,
+            self.useUnixDomainSocket,
+            prolog_path=self.prologPath,
+        ) as server:
+
+            with server.create_thread() as client:
+                # Send a json value that is known to throw during json serialization to make sure the code
+                # is robust to serialization failures
+                caughtException = False
+                try:
+                    result = client.query("X=json([X - 1]).")
+                except PrologError as error:
+                    assert error.is_prolog_exception("domain_error")
+                    caughtException = True
+                assert caughtException
+
+                caughtException = False
+                try:
+                    result = client.query("open_null_stream(X).")
+                except PrologError as error:
+                    assert error.is_prolog_exception("type_error")
+                    caughtException = True
+                assert caughtException
+
+    def test_variable_attributes(self):
+        with PrologMQI(
+            self.launchServer,
+            self.serverPort,
+            self.password,
+            self.useUnixDomainSocket,
+            prolog_path=self.prologPath
+        ) as server:
+
+            with server.create_thread() as client:
+                result = client.query("member(X, [A, B, C]), put_attr(X, my_module, x).")
+                self.assertEqual([{'$residuals': [{'args': ['A', 'my_module', 'x'], 'functor': 'put_attr'}], 'X': 'A', 'A': 'A',
+                  'B': '_', 'C': '_'},
+                 {'$residuals': [{'args': ['B', 'my_module', 'x'], 'functor': 'put_attr'}], 'X': 'B', 'A': '_',
+                  'B': 'B', 'C': '_'},
+                 {'$residuals': [{'args': ['C', 'my_module', 'x'], 'functor': 'put_attr'}], 'X': 'C', 'A': '_',
+                  'B': '_', 'C': 'C'}], result)
+
 
 def run_tcpip_performance_tests(suite):
     suite.addTest(TestPrologMQI("skip_test_protocol_overhead"))
@@ -1337,6 +1393,20 @@ def run_unix_domain_sockets_performance_tests(suite):
     )
 
 
+# Returns None if there is a reason why we can't use domain sockets
+# such as: this is not Unix, the path is too long, etc.
+def unix_domain_socket_path_if_available():
+    if os.name != "nt":
+        # unixDomainSocket() should be used if non-windows
+        socketPath = mkdtemp()
+        unixDomainSocket = PrologMQI.unix_domain_socket_file(socketPath)
+        if len(unixDomainSocket) <= 104:
+            return unixDomainSocket
+
+    # Couldn't use domain sockets due to platform or path length
+    return None
+
+
 def load_tests(loader, standard_tests, pattern):
     global essentialOnly
     global failOnUnlikely
@@ -1348,12 +1418,13 @@ def load_tests(loader, standard_tests, pattern):
     # run_unix_domain_sockets_performance_tests(suite)
 
     # Tests a specific test
-    # suite.addTest(TestPrologMQI('test_goal_expansion'))
+    # suite.addTest(TestPrologMQI('test_async_query'))
     # return suite
 
     # Tests a specific test with parameters set
-    # suite.addTest(ParametrizedTestCase.parametrize(TestPrologMQI, test_item_name="test_sync_query", launchServer=False,
+    # suite.addTest(ParametrizedTestCase.parametrize(TestPrologMQI, test_item_name="test_variable_attributes", launchServer=False,
     #                                                serverPort=4242, password="debugnow"))
+    # return suite
 
     # Tests a specific test 100 times
     # for index in range(0, 100):
@@ -1361,31 +1432,18 @@ def load_tests(loader, standard_tests, pattern):
 
     # Run full test suite using Unix Domain Sockets when appropriate as "main" way to connect
     # Tests include both Port and Unix Domain socket tests so both are tested in either mode
-    if os.name == "nt":
-        suite.addTest(
-            ParametrizedTestCase.parametrize(
-                TestPrologMQI,
-                essentialOnly=essentialOnly,
-                failOnUnlikely=failOnUnlikely,
-                launchServer=True,
-                useUnixDomainSocket=None,
-                serverPort=None,
-                password=None,
-            )
-        )
-    else:
-        socketPath = tempfile.mkdtemp()
-        suite.addTest(
-            ParametrizedTestCase.parametrize(
-                TestPrologMQI,
-                essentialOnly=essentialOnly,
-                failOnUnlikely=failOnUnlikely,
-                launchServer=True,
-                useUnixDomainSocket=PrologMQI.unix_domain_socket_file(socketPath),
-                serverPort=None,
-                password=None,
-            )
+    unixDomainSocket = unix_domain_socket_path_if_available()
+    suite.addTest(
+        ParametrizedTestCase.parametrize(
+            TestPrologMQI,
+            essentialOnly=essentialOnly,
+            failOnUnlikely=failOnUnlikely,
+            launchServer=True,
+            useUnixDomainSocket=unixDomainSocket,
+            serverPort=None,
+            password=None,
         )
+    )
 
     return suite
 
