@@ -3,7 +3,7 @@
 # Author:        Jan Wielemaker
 # E-mail:        jan@swi-prolog.org
 # WWW:           http://www.swi-prolog.org
-# Copyright (c)  2023, SWI-Prolog Solutions b.v.
+# Copyright (c)  2023-2024, SWI-Prolog Solutions b.v.
 # All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
@@ -72,7 +72,7 @@ if not hasattr(_swipl, 'call'):
 # Versions
 
 # 10000*major + 100*minor + patch
-version_num=10103
+version_num=10400
 
 def version_str(num=version_num):
     """
@@ -202,21 +202,23 @@ class query:
         return self
     def __next__(self):
         """Implement iter protocol.  Returns a dict as janus.query_once()"""
-        rc = _swipl.next_solution(self.state)
-        if rc == False or rc["truth"] == False:
+        rc = self.next()
+        if rc is None:
             raise StopIteration()
-        else:
-            return rc
+        return rc
+    def __enter__(self):
+        """Implement context manager protocol"""
+        return self
+    def __exit__(self, type, value, tb):
+        """Implement context manager protocol"""
+        self.close()
     def __del__(self):
         """Close the Prolog query"""
-        _swipl.close_query(self.state)
+        self.close()
     def next(self):
         """Allow for explicit enumeration,  Returns None or a dict"""
         rc = _swipl.next_solution(self.state)
-        if rc == False or rc["truth"] == False:
-            return None
-        else:
-            return rc
+        return None if rc == False or rc["truth"] == False else rc
     def close(self):
         """Explicitly close the query."""
         _swipl.close_query(self.state)
@@ -253,7 +255,7 @@ def once(query, inputs={}, keep=False, truth_vals=TruthVal.PLAIN_TRUTHVALS):
     Deprecated.  Renamed to query_once().
     """
     return query_once(query, inputs, keep, truth)
-    
+
 ################################################################
 # Functional style interface
 
@@ -464,7 +466,7 @@ class Term:
     in Python.  Instances are created if data is passed to Python as
     `prolog(Term)`.  Upon transforming the data back to Prolog, the
     interface recovers a copy of the original Prolog terms.
-    
+
     The user should never create instances of this explicitly.
     """
 
@@ -582,3 +584,32 @@ def connect_io(stdin=True, stdout=True, stderr=True):
         sys.stdout = PrologIO("user_output", io.BytesIO(), line_buffering=True)
     if ( stderr ):
         sys.stderr = PrologIO("user_error",  io.BytesIO(), write_through=True)
+
+
+################################################################
+# Deal with interrupts
+
+def heartbeat_tick():
+    i = 1
+
+def heartbeat(n=10000):
+    """
+    Make Prolog call Python every `N` inferences.  This may be required
+    to allow Python processing signals such as a keyboard interrupt while
+    Prolog is running.  As Python only processes signals in the main thread,
+    it is enough to call this once from the main thread.
+
+    A higher number keeps signals queued for longer, while a lower number
+    harms the Prolog performance.  Note that _inferences_ can take really
+    long of Prolog is calling foreign code.
+
+    Parameters
+    ----------
+    n: int
+        Number of inferences.  Defaults to 10,000.
+    """
+    consult("py_heartbeat", """
+prolog:heartbeat :-
+    py_call(janus_swi:heartbeat_tick()).
+""")
+    query_once("set_prolog_flag(heartbeat, N)", {"N":n})
