@@ -3,7 +3,7 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2008-2023, University of Amsterdam
+    Copyright (c)  2008-2024, University of Amsterdam
 			      VU University Amsterdam
 			      SWI-Prolog Solutions b.v.
     All rights reserved.
@@ -60,7 +60,7 @@ extern "C" {
 /* PLVERSION_TAG: a string, normally "", but for example "rc1" */
 
 #ifndef PLVERSION
-#define PLVERSION 90202
+#define PLVERSION 90208
 #endif
 #ifndef PLVERSION_TAG
 #define PLVERSION_TAG ""
@@ -483,6 +483,7 @@ PL_EXPORT(int)		PL_assert(term_t term, module_t m, int flags);
 PL_EXPORT(term_t)	PL_new_term_refs(size_t n);
 PL_EXPORT(term_t)	PL_new_term_ref(void);
 PL_EXPORT(term_t)	PL_copy_term_ref(term_t from);
+PL_EXPORT(void)		PL_free_term_ref(term_t t);
 PL_EXPORT(void)		PL_reset_term_refs(term_t r);
 
 			/* Constants */
@@ -876,6 +877,9 @@ PL_EXPORT(int)		PL_same_compound(term_t t1, term_t t2);
 PL_EXPORT(int)		PL_warning(const char *fmt, ...) WPRINTF12;
 PL_EXPORT(int)		PL_warningX(const char *fmt, ...);
 PL_EXPORT(void)		PL_fatal_error(const char *fmt, ...) WPRINTF12;
+PL_EXPORT(void)		PL_api_error(const char *fmt, ...) WPRINTF12;
+PL_EXPORT(void)		PL_system_error(const char *fmt, ...) WPRINTF12;
+PL_EXPORT(int)		PL_print_message(atom_t severity, ...) WUNUSED;
 
 		 /*******************************
 		 *      RECORDED DATABASE	*
@@ -1289,6 +1293,7 @@ PL_EXPORT(intptr_t)	PL_query(int);	/* get information from Prolog */
 
 #define PL_THREAD_NO_DEBUG	0x01	/* Start thread in nodebug mode */
 #define PL_THREAD_NOT_DETACHED	0x02	/* Allow Prolog to join */
+#define PL_THREAD_CUR_STREAMS   0x04	/* Copy current{input,output} */
 
 typedef enum
 { PL_THREAD_CANCEL_FAILED = FALSE,	/* failed to cancel; try abort */
@@ -1345,22 +1350,24 @@ PL_EXPORT(int)		PL_destroy_engine(PL_engine_t engine);
 		 *******************************/
 typedef _PLS(table)	  *hash_table_t;
 typedef _PLS(table_enum) *hash_table_enum_t;
+typedef void *table_key_t;	/* introduced abstract types for forward compatibility */
+typedef void *table_value_t;
 
 #define PL_HT_NEW	0x0001
 #define PL_HT_UPDATE	0x0002
 
 PL_EXPORT(hash_table_t)	PL_new_hash_table(int size,
-					  void (*free_symbol)(void *n, void *v));
+					  void (*free_symbol)(table_key_t n, table_value_t v));
 PL_EXPORT(int)		PL_free_hash_table(hash_table_t table);
-PL_EXPORT(void*)	PL_lookup_hash_table(hash_table_t table, void *key);
-PL_EXPORT(void*)	PL_add_hash_table(hash_table_t table,
-					  void *key, void *value, int flags);
-PL_EXPORT(void*)	PL_del_hash_table(hash_table_t table, void *key);
+PL_EXPORT(table_value_t) PL_lookup_hash_table(hash_table_t table, table_key_t key);
+PL_EXPORT(table_value_t) PL_add_hash_table(hash_table_t table,
+					   table_key_t key, table_value_t value, int flags);
+PL_EXPORT(table_value_t) PL_del_hash_table(hash_table_t table, table_key_t key);
 PL_EXPORT(int)		PL_clear_hash_table(hash_table_t table);
 PL_EXPORT(hash_table_enum_t) PL_new_hash_table_enum(hash_table_t table);
 PL_EXPORT(void)		PL_free_hash_table_enum(hash_table_enum_t e);
 PL_EXPORT(int)		PL_advance_hash_table_enum(hash_table_enum_t e,
-						   void **key, void **value);
+						   table_key_t *key, table_value_t *value);
 
 
 		 /*******************************
