@@ -121,7 +121,7 @@ string_summary(word string, unsigned int maxlen)
 { GET_LD
   PL_chars_t txt;
 
-  if ( !get_string_text(string, &txt PASS_LD) )
+  if ( !get_string_text(string, &txt) )
     return NULL;
 
   return text_summary(&txt, '"', maxlen);
@@ -142,7 +142,7 @@ predicateName(Definition def)
     return "(nil)";
 
   if ( def->module != MODULE_user && !isUserSystemPredicate(def) )
-  { if ( def->module )
+  { if ( def->module && GD->cleaning != CLN_DATA )
       strcpy(e, atom_summary(def->module->name, 50));
     else
       strcpy(e, "(nil)");
@@ -152,7 +152,7 @@ predicateName(Definition def)
   strcpy(e, atom_summary(def->functor->name, 50));
   e += strlen(e);
   *e++ = '/';
-  Ssprintf(e, "%d", def->functor->arity);
+  Ssprintf(e, "%zd", def->functor->arity);
 
   return buffer_string(tmp, BUF_STACK);
 }
@@ -171,7 +171,7 @@ functorName(functor_t f)
   strcpy(e, atom_summary(fd->name, 50));
   e += strlen(e);
   *e++ = '/';
-  Ssprintf(e, "%d", fd->arity);
+  Ssprintf(e, "%zd", fd->arity);
 
   return buffer_string(tmp, BUF_STACK);
 }
@@ -193,10 +193,10 @@ keyName(word key)
 	{ GET_LD
 	  number n;
 
-	  get_number(key, &n PASS_LD);
+	  get_number(key, &n);
 	  switch(n.type)
 	  { case V_INTEGER:
-	      Ssprintf(tmp, "%lld", n.value.i);
+	      Ssprintf(tmp, "%" PRIi64, n.value.i);
 	      break;
 	    case V_FLOAT:
 	      Ssprintf(tmp, "%f", n.value.f);
@@ -244,9 +244,9 @@ generationName(gen_t gen)
   { int tid    = (gen-GEN_TRANSACTION_BASE)/GEN_TRANSACTION_SIZE;
     int64_t g2 = (gen-GEN_TRANSACTION_BASE)%GEN_TRANSACTION_SIZE;
 
-    Ssprintf(tmp, "%d@%lld", tid, (int64_t)g2);
+    Ssprintf(tmp, "%d@%" PRIi64, tid, (int64_t)g2);
   } else
-  { Ssprintf(tmp, "%lld", (int64_t)gen);
+  { Ssprintf(tmp, "%" PRIi64, (int64_t)gen);
   }
 
   return buffer_string(tmp, BUF_STACK);
@@ -296,6 +296,7 @@ isUserSystemPredicate(Definition def)
 { GET_LD
 
   if ( true(def, P_LOCKED) &&
+       GD->cleaning != CLN_DATA &&
        isCurrentProcedure(def->functor->functor, MODULE_user) )
     succeed;
 
